@@ -11,8 +11,14 @@ import requests
 
 from . import deanonymizer
 
+logger = logging.getLogger(__name__)
+
 
 class EvaluationResource:
+    """This resource is intended for evaluating membership inference attacks
+    targeting estimators which follow the supervised learning paradigm.
+    """
+
     def __init__(
         self,
         anonymizer_identifier: str,
@@ -23,6 +29,26 @@ class EvaluationResource:
         evaluation_data_url: str,
         utility_evaluation_url: str,
     ) -> None:
+        """
+        Parameters
+        ----------
+        anonymizer_identifier : str
+            The attack target's identifier.
+        deanonymizer_identifier : str
+            The attacker's identifier.
+        model_filepath : str | Path
+            Where to save the attack model to disk after fitting.
+        model_loader : Callable[[str  |  Path], deanonymizer.SupervisedLearningMIA]
+            How to load a fitted attack model from disk.
+        default_batch_size : int
+            The batch size to use for membership inference if not provided
+            otherwise. Choose sensibly to avoid too much resource consumption.
+        evaluation_data_url : str
+            Where to obtain attack success evaluation data from.
+        utility_evaluation_url : str
+            Where to submit inferred memberships to, such that they will be
+            evaluated.
+        """
         self._anon_id = anonymizer_identifier
         self._deanon_id = deanonymizer_identifier
         self._model_filepath = Path(model_filepath)
@@ -41,20 +67,24 @@ class EvaluationResource:
         try:
             data_split = req.get_param("data_split", required=True)
         except falcon.HTTPBadRequest:
-            error_msg = "Query parameter 'data_split' is missing!"
-            logging.exception(error_msg)
-            raise falcon.HTTPBadRequest(description=error_msg)
+            raise falcon.HTTPBadRequest(
+                description="Query parameter 'data_split' is missing!"
+            )
 
         if data_split not in ["tuning", "validation"]:
-            error_msg = "Query parameter data_split needs to be either 'tuning' or "
-            "'validation'."
-            logging.exception(error_msg)
-            raise falcon.HTTPBadRequest(description=error_msg)
+            raise falcon.HTTPBadRequest(
+                description="Query parameter data_split needs to be either 'tuning' or "
+                "'validation'."
+            )
 
         array = utils.get_named_arrays_or_raise(
             self._evaluation_data_url,
             expected_array_labels=self._expected_array_labels,
-            params=dict(data_split=data_split),
+            params=dict(
+                data_split=data_split,
+                anonymizer=self._anon_id,
+                deanonymizer=self._deanon_id,
+            ),
             timeout=self._timeout,
         )
 
@@ -62,10 +92,19 @@ class EvaluationResource:
             array[self._expected_array_labels[0]],
             array[self._expected_array_labels[1]],
         )
+        logger.debug(
+            "Inferring memberships (context: evaluation) for features with shape "
+            f"{X.shape} and dtype {X.dtype}, and targets with shape {y.shape} and dtype "
+            f"{y.dtype}."
+        )
         memberships = self._loaded_model.infer_memberships(
             X=X, y=y, batch_size=self._default_batch_size
         )
 
+        logger.debug(
+            f"Submitting memberships of shape {memberships.shape} and dtype "
+            f"{memberships.dtype} to {self._utility_evaluation_url} for evaluation."
+        )
         evaluation_response = requests.post(
             url=self._utility_evaluation_url,
             data=utils.named_ndarrays_to_bytes(dict(prediction=memberships)),
@@ -86,25 +125,30 @@ class EvaluationResource:
             )
             resp.status = falcon.HTTP_CREATED
         else:
-            error_msg = "Utility evaluation failed."
-            logging.exception(error_msg)
-            raise falcon.HTTPInternalServerError(description=error_msg)
+            raise falcon.HTTPInternalServerError(
+                description="Utility evaluation failed."
+            )
 
     def _load_most_recent_model(self) -> None:
         if not self._model_filepath.exists():
-            error_msg = "This deanonymizer is not fitted yet."
-            logging.exception(error_msg)
             raise falcon.HTTPBadRequest(
-                description=error_msg,
+                description="This deanonymizer is not fitted yet.",
             )
         mod_time_from_disk = datetime.fromtimestamp(
             self._model_filepath.stat().st_mtime
         )
         if _is_older(self._loaded_model_modification_time, mod_time_from_disk):
+            logger.debug(
+                "Loading model from disk as it is more recent than the already loaded "
+                "model."
+            )
             self._loaded_model = self._load_model(self._model_filepath)
             self._loaded_model_modification_time = mod_time_from_disk
         else:
-            # keep the current model as it is already recent enough
+            logger.debug(
+                "Keeping the currently loaded model, is it is already the most recent "
+                "one."
+            )
             pass
 
 
@@ -167,7 +211,8 @@ def supervised_learning_MIA_server_factory(
     utility_evaluation_url : str
         Where to submit inferred memberships to, for evaluation.
     model_loader : Callable[[str  |  Path], deanonymizer.SupervisedLearningMIA]
-        _description_
+        A function to load a deanonymizer, that has been saved to disk by using
+        `deanonymizer_obj.save(...)`.
 
     Returns
     -------
